aboutsummaryrefslogtreecommitdiffstats
path: root/e-util/e-util.h
diff options
context:
space:
mode:
authorMatthew Barnes <mbarnes@redhat.com>2009-05-27 22:29:19 +0800
committerMatthew Barnes <mbarnes@redhat.com>2009-05-27 22:29:19 +0800
commit948235c3d1076dbe6ed2e57a24c16a083bbd9f01 (patch)
tree4133b1adfd94d8f889ca7ad4ad851346518f4171 /e-util/e-util.h
parentcc3a98fc1ad5bb87aa7335f3de404ee7feee1541 (diff)
downloadgsoc2013-evolution-948235c3d1076dbe6ed2e57a24c16a083bbd9f01.tar
gsoc2013-evolution-948235c3d1076dbe6ed2e57a24c16a083bbd9f01.tar.gz
gsoc2013-evolution-948235c3d1076dbe6ed2e57a24c16a083bbd9f01.tar.bz2
gsoc2013-evolution-948235c3d1076dbe6ed2e57a24c16a083bbd9f01.tar.lz
gsoc2013-evolution-948235c3d1076dbe6ed2e57a24c16a083bbd9f01.tar.xz
gsoc2013-evolution-948235c3d1076dbe6ed2e57a24c16a083bbd9f01.tar.zst
gsoc2013-evolution-948235c3d1076dbe6ed2e57a24c16a083bbd9f01.zip
Prefer GLib basic types over C types.
Diffstat (limited to 'e-util/e-util.h')
-rw-r--r--e-util/e-util.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/e-util/e-util.h b/e-util/e-util.h
index 940cfc470f..db35507eb2 100644
--- a/e-util/e-util.h
+++ b/e-util/e-util.h
@@ -58,7 +58,7 @@ gint e_action_compare_by_label (GtkAction *action1,
void e_action_group_remove_all_actions
(GtkActionGroup *action_group);
-char * e_str_without_underscores (const char *s);
+gchar * e_str_without_underscores (const gchar *s);
gint e_str_compare (gconstpointer x,
gconstpointer y);
gint e_str_case_compare (gconstpointer x,
@@ -114,8 +114,8 @@ gchar * e_ascii_dtostr (gchar *buffer,
const gchar *format,
gdouble d);
-/* Alternating char * and int arguments with a NULL char * to end.
- Less than 0 for the int means copy the whole string. */
+/* Alternating gchar * and gint arguments with a NULL gchar * to end.
+ Less than 0 for the gint means copy the whole string. */
gchar * e_strdup_append_strings (gchar *first_string,
...);